==> vlc-2.0.1.tar.xz: vlc-2.0.1/modules/access/dtv/bdagraph.hpp <==
/*****************************************************************************
 * bdagraph.h : DirectShow BDA graph builder header for vlc
 *****************************************************************************
 * Copyright ( C ) 2007 the VideoLAN team
 *
 * Author: Ken Self <kenself(at)optusnet(dot)com(dot)au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * ( at your option ) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

/*****************************************************************************
 * Preamble
 *****************************************************************************/

using namespace std;

#include <wtypes.h>
#include <unknwn.h>
#include <ole2.h>
#include <limits.h>

/* FIXME: mingw.org doesn't define secure versions of
 * http://msdn.microsoft.com/en-us/library/f30dzcf6.aspxu */
#define NO_DSHOW_STRSAFE
#include <dshow.h>

#include <comcat.h>
#include "dtv/bdadefs.h"

class BDAOutput
{
public:
    BDAOutput( vlc_object_t * );
    ~BDAOutput();

    void    Push( block_t * );
    ssize_t Pop(void *, size_t);
    void    Empty();

private:
    vlc_object_t *p_access;
    vlc_mutex_t   lock;
    vlc_cond_t    wait;
    block_t      *p_first;
    block_t     **pp_next;
};

/* The main class for building the filter graph */
class BDAGraph : public ISampleGrabberCB
{
public:
    BDAGraph( vlc_object_t * );
    virtual ~BDAGraph();

    /* */
    int SubmitTuneRequest(void);

    int SetCQAM(long);
    int SetATSC(long);
    int SetDVBT(long, uint32_t, uint32_t, long, int, uint32_t, int);
    int SetDVBC(long, const char *, long);
    int SetDVBS(long, long, uint32_t, int, char, long, long, long);

    /* */
    ssize_t Pop(void *, size_t);

private:
    /* ISampleGrabberCB methods */
    ULONG ul_cbrc;
    STDMETHODIMP_( ULONG ) AddRef( ) { return ++ul_cbrc; }
    STDMETHODIMP_( ULONG ) Release( ) { return --ul_cbrc; }
    STDMETHODIMP QueryInterface( REFIID /*riid*/, void** /*p_p_object*/ )
        { return E_NOTIMPL; }
    STDMETHODIMP SampleCB( double d_time, IMediaSample* p_sample );
    STDMETHODIMP BufferCB( double d_time, BYTE* p_buffer, long l_buffer_len );

    vlc_object_t *p_access;
    CLSID     guid_network_type;
    long      l_tuner_used;        /* Index of the Tuning Device */
    /* registration number for the RunningObjectTable */
    DWORD     d_graph_register;

    BDAOutput       output;

    IMediaControl*  p_media_control;
    IGraphBuilder*  p_filter_graph;
    ITuningSpace*   p_tuning_space;
    ITuneRequest*   p_tune_request;

    ICreateDevEnum* p_system_dev_enum;
    IBaseFilter*    p_network_provider;
    IScanningTuner* p_scanning_tuner;
    IBaseFilter*    p_tuner_device;
    IBaseFilter*    p_capture_device;
    IBaseFilter*    p_sample_grabber;
    IBaseFilter*    p_mpeg_demux;
    IBaseFilter*    p_transport_info;
    ISampleGrabber* p_grabber;

    HRESULT CreateTuneRequest( );
    HRESULT Build( );
    HRESULT FindFilter( REFCLSID clsid, long* i_moniker_used,
        IBaseFilter* p_upstream, IBaseFilter** p_p_downstream );
    HRESULT Connect( IBaseFilter* p_filter_upstream,
        IBaseFilter* p_filter_downstream );
    HRESULT Start( );
    HRESULT Destroy( );
    HRESULT Register( );
    void Deregister( );
};

==> vlc-2.0.5.tar.xz: vlc-2.0.5/modules/access/dtv/bdagraph.hpp <==
/*****************************************************************************
 * bdagraph.h : DirectShow BDA graph builder header for vlc
 *****************************************************************************
 * Copyright ( C ) 2007 the VideoLAN team
 *
 * Author: Ken Self <kenself(at)optusnet(dot)com(dot)au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * ( at your option ) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

/*****************************************************************************
 * Preamble
 *****************************************************************************/

using namespace std;

#include <wtypes.h>
#include <unknwn.h>
#include <ole2.h>
#include <limits.h>

/* FIXME: mingw.org doesn't define secure versions of
 * http://msdn.microsoft.com/en-us/library/f30dzcf6.aspxu */
#define NO_DSHOW_STRSAFE
#include <dshow.h>

#include <comcat.h>
#include "dtv/bdadefs.h"

class BDAOutput
{
public:
    BDAOutput( vlc_object_t * );
    ~BDAOutput();

    void    Push( block_t * );
    ssize_t Pop(void *, size_t);
    void    Empty();

private:
    vlc_object_t *p_access;
    vlc_mutex_t   lock;
    vlc_cond_t    wait;
    block_t      *p_first;
    block_t     **pp_next;
};

/* The main class for building the filter graph */
class BDAGraph : public ISampleGrabberCB
{
public:
    BDAGraph( vlc_object_t * );
    virtual ~BDAGraph();

    /* */
    int SubmitTuneRequest(void);
    unsigned EnumSystems(void);
    int SetInversion(int);
    float GetSignalStrength(void);
    float GetSignalNoiseRatio(void);

    int SetCQAM(long);
    int SetATSC(long);
    int SetDVBT(long, uint32_t, uint32_t, long, int, uint32_t, int);
    int SetDVBC(long, const char *, long);
    int SetDVBS(long, long, uint32_t, int, char, long, long, long);

    /* */
    ssize_t Pop(void *, size_t);

private:
    /* ISampleGrabberCB methods */
    ULONG ul_cbrc;
    STDMETHODIMP_( ULONG ) AddRef( ) { return ++ul_cbrc; }
    STDMETHODIMP_( ULONG ) Release( ) { return --ul_cbrc; }
    STDMETHODIMP QueryInterface( REFIID /*riid*/, void** /*p_p_object*/ )
        { return E_NOTIMPL; }
    STDMETHODIMP SampleCB( double d_time, IMediaSample* p_sample );
    STDMETHODIMP BufferCB( double d_time, BYTE* p_buffer, long l_buffer_len );

    vlc_object_t *p_access;
    CLSID     guid_network_type;   /* network type in use */
    long      l_tuner_used;        /* Index of the Tuning Device in use */
    unsigned  systems;             /* bitmask of all tuners' network types */

    /* registration number for the RunningObjectTable */
    DWORD     d_graph_register;

    BDAOutput       output;

    IMediaControl*  p_media_control;
    IGraphBuilder*  p_filter_graph;
    ITuningSpaceContainer*      p_tuning_space_container;
    ITuningSpace*               p_tuning_space;
    ITuneRequest*               p_tune_request;

    IDVBTuningSpace*            p_dvb_tuning_space;
    IDVBSTuningSpace*           p_dvbs_tuning_space;
#if 0
    IDigitalCableTuningSpace*   p_cqam_tuning_space;
    IATSCTuningSpace*           p_atsc_tuning_space;
#endif

    ICreateDevEnum* p_system_dev_enum;
    IBaseFilter*    p_network_provider;
    IBaseFilter*    p_tuner_device;
    IBaseFilter*    p_capture_device;
    IBaseFilter*    p_sample_grabber;
    IBaseFilter*    p_mpeg_demux;
    IBaseFilter*    p_transport_info;
    IScanningTuner* p_scanning_tuner;
    ISampleGrabber* p_grabber;

    HRESULT SetUpTuner( REFCLSID guid_this_network_type );
    HRESULT GetNextNetworkType( CLSID* guid_this_network_type );
    HRESULT Build( );
    HRESULT Check( REFCLSID guid_this_network_type );
    HRESULT GetFilterName( IBaseFilter* p_filter, char** psz_bstr_name );
    HRESULT GetPinName( IPin* p_pin, char** psz_bstr_name );
    unsigned GetSystem( REFCLSID clsid );
    HRESULT ListFilters( REFCLSID this_clsid );
    HRESULT FindFilter( REFCLSID clsid, long* i_moniker_used,
        IBaseFilter* p_upstream, IBaseFilter** p_p_downstream );
    HRESULT Connect( IBaseFilter* p_filter_upstream,
        IBaseFilter* p_filter_downstream );
    HRESULT Start( );
    HRESULT Destroy( );
    HRESULT Register( );
    void Deregister( );
};
